package com.intel;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.InetSocketAddress;
import java.net.SocketTimeoutException;
import java.security.KeyManagementException;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.UnrecoverableKeyException;
import java.security.cert.CertificateException;
import java.util.Properties;

import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSocket;
import javax.net.ssl.SSLSocketFactory;

public class SSLSocketClient {

    String socketServerIp = "";
    int port = 9999;
    int timeout = 10000000;
    String homeFolder = "/etc/intel/cloudsecurity/";
    TlsPolicy tlsPolicy;
    
    public SSLSocketClient() {
        readPropertiesFile();
        tlsPolicy = new InsecureTlsPolicy(new InternetAddress(socketServerIp));
    }

  public byte[] sendRequestWithSSLSocket() throws Exception {
     byte[] identityInput = "<identity_request></identity_request>".getBytes();
     byte[] data = identityInput;
     SSLSocketFactory sslsocketfactory =getSSLContext().getSocketFactory();
     SSLSocket sock = (SSLSocket) sslsocketfactory.createSocket();
     try {   
         sock.connect(new InetSocketAddress(socketServerIp, port), timeout);
         InputStream sockInput = sock.getInputStream();
         OutputStream sockOutput = sock.getOutputStream();

         System.out.println("About to start reading/writing to/from socket.");

         byte[] buf = new byte[5000];
             sockOutput.write(data, 0, data.length);
         int bytes_read = sockInput.read(buf);
         System.out.println("Received " + bytes_read + " bytes to server and received them back again, msg = " 
                    +new String(buf));
         return buf;
     }
     catch(SocketTimeoutException e){
        System.out.println("Exception:" +e);
        throw new Exception(e);
     }
     finally {
         sock.close();        
     }
 }
 
  private SSLContext getSSLContext() throws NoSuchAlgorithmException, KeyManagementException {
     SSLContext ctx = SSLContext.getInstance("SSL");
     ctx.init(null, new javax.net.ssl.TrustManager[]{ tlsPolicy.getTrustManager() }, null);
     return ctx;
  }
  
  private void readPropertiesFile (){
      String propertiesFileName =  "hisprovisioner.properties";
      String SOCKET_SERVER_IP = "socketServerIp";
      InputStream PropertyFile = null;
      try{
          PropertyFile = new FileInputStream(homeFolder +  propertiesFileName);
          Properties PrivacyCaProperties = new Properties();
          PrivacyCaProperties.load(PropertyFile);
          socketServerIp = PrivacyCaProperties.getProperty(SOCKET_SERVER_IP, "127.0.0.1");
      } catch (FileNotFoundException e) {
          System.out.println("Error finding Privacy CA properties file: cannot continue. Please place properties file in: home folder." + homeFolder);
          System.out.println(e.toString());
      } catch (IOException e) {
          System.out.println("Error loading Privacy CA properties file: cannot continue." + homeFolder);
      }
      finally{
           try {
               if (PropertyFile != null)
                   PropertyFile.close();
           } catch (IOException e) {
              e.printStackTrace();
           }
      }
  }
}
