/*
 * Copyright (c) 2013, Intel Corporation. 
 * All rights reserved.
 * 
 * The contents of this file are released under the BSD license, you may not use this file except in compliance with the License.
 * 
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 * 
 * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 * Neither the name of Intel Corporation nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package com.intel;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.security.Security;

import javax.net.ssl.SSLServerSocket;
import javax.net.ssl.SSLServerSocketFactory;
import javax.net.ssl.SSLSocket;

import org.bouncycastle.jce.provider.BouncyCastleProvider;

public class SSLSocketServer {

    private SSLServerSocket serverSock = null;
    
    static int port = 9999;

    public SSLSocketServer(int serverPort) throws Exception {
        try {

            SSLServerSocketFactory sslserversocketfactory =
                    (SSLServerSocketFactory) SSLServerSocketFactory.getDefault();
            serverSock =
                    (SSLServerSocket) sslserversocketfactory.createServerSocket(port);
        } catch (IOException e) {
            System.out.println("Error while creating socket." +e);
            throw e;
        }
    }

    public void waitForConnections() {
        SSLSocket sock = null;
        while (true) {
            try {

                sock = (SSLSocket) serverSock.accept();

                handleConnection(sock.getInputStream(), sock.getOutputStream());

            } catch (Exception e) {
                System.out.println("e:" +e);
            } finally {
              
                try {
                    sock.close();
                } catch (IOException ex) {
                    System.out.println("e:" +ex);
                }
            }
        }
    }

    public static void main(String argv[]) {

        SSLSocketServer server;
        try {
            Security.addProvider(new BouncyCastleProvider());
            server = new SSLSocketServer(port);
            server.waitForConnections();
        } catch (Exception e) {
            System.out.println("Error while starting TA:" +e);
        }
        
    }
    
    public void handleConnection(InputStream sockInput, OutputStream sockOutput) {

        byte[] buf = new byte[1024];
        
        try {
            int bytes_read ;
            // This call to read() will wait forever, until the
            // program on the other side either sends some data,
            // or closes the socket.
            bytes_read = sockInput.read(buf, 0, buf.length);
            
            // If the socket is closed, sockInput.read() will return -1.
            if (bytes_read < 0) {
                System.out.println("Tried to read from socket read() returned < 0,  Closing socket.");
                return;

            }
            System.out.println("Received data from socket.");
            
            writeResponse(sockOutput,byteArrayToHexString(CreateIdentity.createIdentity()));
        } catch (Throwable e) { // Make sure all the exceptions are caught here
                                // and return and response to client
            System.out.println("Exception reading from/writing to socket, e = {0}," +e);
            
        } 
    }
    
    private void writeResponse(OutputStream sockOutput, String response){
        try {
            if( response != null){
                sockOutput
                    .write(response.getBytes(), 0, response.getBytes().length);
            }else{
                sockOutput
                    .write("".getBytes(), 0, "".getBytes().length);
            }
            sockOutput.flush();

        } catch (Exception e) {
            System.out.println("Error while writing back to sock output:" +e);
        }
    }
    
    private  String byteArrayToHexString(byte[] b) {
        StringBuffer sb = new StringBuffer();
        String returnStr = "";
        for (int i = 0; i < b.length; i++) {
            String singleByte = Integer.toHexString(b[i] & 0xff);
            if (singleByte.length() != 2) singleByte = "0" + singleByte;
            returnStr = sb.append(singleByte).toString();
        }
        return returnStr;
    }
    
}
